-- CombatLog parser
-- processArgs receives all args from any combat log event (...) and returns a table with named indices according to wowwiki prefix/suffix arg names:  http://www.wowwiki.com/API_COMBAT_LOG_EVENT
--  Developed by Oridan of Kazzak-EU
-- please leave credit if you use this.

-- process order to createtables with named properties of combat log event args.
SpellReminder.combatlog_event_args = {
	{'',						{'timestamp','event','sourceGUID','sourceName','sourceFlags','destGUID','destName','destFlags'}},
	-- special
	{'DAMAGE_SHIELD_MISSED',	{'missType'}},
	{'DAMAGE_SHIELD',			{'spellId','spellName','spellSchool','amount','school','resisted','blocked','absorbed','critical','glancing','crushing'}},
	{'DAMAGE_SPLIT',			{'spellId','spellName','spellSchool','amount','school','resisted','blocked','absorbed','critical','glancing','crushing'}},
	{'ENCHANT_APPLIED',			{'spellName','itemID','itemName'}},
	{'ENCHANT_REMOVED',			{'spellName','itemID','itemName'}},
	{'PARTY_KILL',				},
	{'UNIT_DIED',				},
	{'UNIT_DESTROYED',			},
	-- prefixes
	{'SWING',					},
	{'SPELL_PERIODIC',			{'spellId','spellName','spellSchool'}},
	{'SPELL',					{'spellId','spellName','spellSchool'}},
	{'RANGE',					{'spellId','spellName','spellSchool'}},
	{'ENVIRONMENTAL',			{'environmentalType'}},
	-- suffixes
	{'_DAMAGE',					{'amount','school','resisted','blocked','absorbed','critical','glancing','crushing'}},
	{'_MISSED',					{'missType'}},
	{'_HEAL',					{'amount','critical'}},
	{'_ENERGIZE',				{'amount','powerType'}},
	{'_DRAIN',					{'amount','powerType','extraAmount'}},
	{'_LEECH',					{'amount','powerType','extraAmount'}},
	{'_INTERRUPT',				{'extraSpellID','extraSpellName','extraSpellSchool'}},
	{'_DISPEL_FAILED',			{'extraSpellID','extraSpellName','extraSpellSchool'}},
	{'_EXTRA_ATTACKS',			{'amount'}},
	{'_AURA_APPLIED_DOSE',		{'auraType','amount'}},
	{'_AURA_APPLIED',			{'auraType'}},
	{'_AURA_REMOVED_DOSE',		{'auraType','amount'}},
	{'_AURA_REMOVED',			{'auraType'}},
	{'_AURA_DISPELLED',			{'extraSpellID','extraSpellName','extraSpellSchool','auraType'}},
	{'_AURA_STOLEN',			{'extraSpellID','extraSpellName','extraSpellSchool'}},
	{'_CAST_START',				},
	{'_CAST_SUCCESS',			},
	{'_CAST_FAILED',			{'failedType'}},
	{'_INSTAKILL',				},
	{'_DURABILITY_DAMAGE_ALL',	},
	{'_DURABILITY_DAMAGE',		},
	{'_CREATE',					},
	{'_SUMMON',					},
}

function processArgs(...)
	local data = {...}
	local eventName,eventNameProcess = data[2],data[2]
	
	local eventArgs = {}
	local argsProcessedCount = 0;
	
	table.foreach(SpellReminder.combatlog_event_args,function (_,set)
		if eventNameProcess == "" or eventNameProcess == nil then return false end
		local sectionName, paramNames, matches = set[1], set[2], 0
		eventNameProcess, matches = string.gsub(eventNameProcess,'^'..sectionName,'')
		if type(paramNames) == "table" and (matches > 0 or type(key) == "number") then
			table.foreach(paramNames,function (_,val)
				eventArgs[val] = data[argsProcessedCount+1]
				argsProcessedCount = argsProcessedCount+1
			end)
		end
	end)
	
	if eventNameProcess ~= "" then
		SpellReminder:Print("Event not fully processed: "..eventName.."  Remaining: "..eventNameProcess)
	end
	
	return eventArgs
end
